//
//  ViewController.swift
//  Eyre
//
//  Created by Mark Meretzky on 11/20/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;
import MediaPlayer;	//for MPMoviePlayerController

class ViewController: UIViewController {
	let controller: MPMoviePlayerController = MPMoviePlayerController();

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);

		let bundle: NSBundle? = NSBundle.mainBundle();
		if bundle == nil {
			println("Could not access main bundle.");
			return;
		}
		println("bundle.bundlePath = \(bundle!.bundlePath)\n");

		let filename: String? = bundle!.pathForResource("eyre", ofType: "mp4");
		if filename == nil {
			println("could not find file sneeze.m4v");
			return;
		}
		println("filename = \(filename!)\n");

		let url: NSURL? = NSURL(fileURLWithPath: filename!);
		if url == nil {
			println("could not create URL for file \(filename)");
			return;
		}
		println("url = \(url!)\n");

		controller = MPMoviePlayerController(contentURL: url!);
		println("controller!.contentURL = \(controller.contentURL)\n");

		controller.shouldAutoplay = false;	//don't start spontaneously
		controller.scalingMode = MPMovieScalingMode.None;
		controller.controlStyle = MPMovieControlStyle.Fullscreen;
		controller.movieSourceType = MPMovieSourceType.File; //vs. stream
		controller.prepareToPlay();

		let center: NSNotificationCenter = NSNotificationCenter.defaultCenter();

		center.addObserver(self,
			selector: "playbackDidFinish:",
			name: MPMoviePlayerPlaybackDidFinishNotification,
			object: controller);
	}

	override func loadView() {
		//Implant a reference to this view controller into the newborn View.
		view = View(viewController: self);
	}

	override func viewDidLoad() {
		super.viewDidLoad()
		// Do any additional setup after loading the view, typically from a nib.
	}

	func touchUpInside(button: UIButton!) {
		var title: String? = button.titleForState(UIControlState.Normal);
		if title == nil {
			title = "untitled";
		}
		println("touchUpInside title = \(title!)");

		//Make sure the controller's view is the same size
		//as the View it's about to replave.
		controller.view.frame = view.frame;

		//Remove the View from the UIWindow.
		view.removeFromSuperview();

		//Replace the View with the controller's view.
		let application: UIApplication = UIApplication.sharedApplication();
		let appDelegate: AppDelegate = application.delegate! as AppDelegate;
		appDelegate.window!.addSubview(controller.view);

		controller.play();
	}
	
	func playbackDidFinish(notification: NSNotification) {
		//Print the two relevant items in the userInfo dictinary.
		if notification.userInfo != nil {
			let userInfo:[NSObject: AnyObject] = notification.userInfo!;
			let i: Int? = userInfo[MPMoviePlayerPlaybackDidFinishReasonUserInfoKey] as? Int;
			if i != nil && i! != MPMovieFinishReason.PlaybackEnded.rawValue {
				println("playbackDidFinish: reason = \(i!)");
			}
			let error: NSError? = userInfo["error"] as? NSError;
			if error != nil {
				println("playbackDidFinish: error =  \(error!)");
			}
		}

		//Remove the controller's view from the window.
		controller.view.removeFromSuperview();

		//Replace the controller's view with the View.
		let application: UIApplication = UIApplication.sharedApplication();
		let appDelegate: AppDelegate = application.delegate! as AppDelegate;
		appDelegate.window!.addSubview(view);
	}

	override func supportedInterfaceOrientations() -> Int {
		return Int(UIInterfaceOrientationMask.LandscapeLeft.rawValue);
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning()
		// Dispose of any resources that can be recreated.
	}


}

